@@ -16,4 +16,8 @@ rm config.h
 
 echo Deleting the Gip binary...
 [ -e gip ] && rm gip
+
+echo Deleting desktop and menu file...
+[ -e gip.desktop ] && rm gip.desktop
+[ -e gip.xml     ] && rm gip.xml
 echo Finished.
