@@ -14,7 +14,9 @@ xgettext -jC -k"_" -k"N_" --from-code ISO-8859-1 -o gip.pot $FILES \
 # Generate .mo files from all .po files.
 find . -name "*.po" | while read POFILE; do
   MOFILE=`echo $POFILE | sed 's/\.po$/\.mo/'`
+  echo -n $POFILE...
   msgfmt -o $MOFILE $POFILE || exit 1
+  echo done.
 done
 
 # Generate a POTFILE.in file for intltool-update support.
