@@ -93,6 +93,9 @@ void Dispatcher::on_ipv4_analyzer_ip_changed(unsigned long ip,
   mainwindow->ipv4_analyzer.set_output_bin_ip(ip);
   mainwindow->ipv4_analyzer.set_output_bin_network(ip & mask);
   mainwindow->ipv4_analyzer.set_output_bin_broadcast(broadcast);
+  mainwindow->ipv4_analyzer.set_output_hex_ip(ip);
+  mainwindow->ipv4_analyzer.set_output_hex_network(ip & mask);
+  mainwindow->ipv4_analyzer.set_output_hex_broadcast(broadcast);
   mainwindow->unlock_signals();
 }
 
@@ -123,6 +126,8 @@ void Dispatcher::on_ipv4_analyzer_mask_changed(unsigned long ip,
   mainwindow->ipv4_analyzer.set_output_broadcast(broadcast);
   mainwindow->ipv4_analyzer.set_output_bin_mask(mask);
   mainwindow->ipv4_analyzer.set_output_bin_broadcast(broadcast);
+  mainwindow->ipv4_analyzer.set_output_hex_mask(mask);
+  mainwindow->ipv4_analyzer.set_output_hex_broadcast(broadcast);
   mainwindow->unlock_signals();
 }
 
@@ -153,6 +158,8 @@ void Dispatcher::on_ipv4_analyzer_pfxlen_changed(unsigned long ip,
   mainwindow->ipv4_analyzer.set_output_broadcast(broadcast);
   mainwindow->ipv4_analyzer.set_output_bin_mask(mask);
   mainwindow->ipv4_analyzer.set_output_bin_broadcast(broadcast);
+  mainwindow->ipv4_analyzer.set_output_hex_mask(mask);
+  mainwindow->ipv4_analyzer.set_output_hex_broadcast(broadcast);
   mainwindow->unlock_signals();
 }
 
