@@ -41,7 +41,7 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   Image*       image = NULL;
   string       str;
   
-  resize(18, 5);
+  resize(24, 5);
   set_border_width(12);
   set_row_spacings(3);
   set_col_spacings(12);
@@ -59,13 +59,13 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   image->set_padding(12, 0);
   attach(*manage(image), 0, 1, 1, 4, FILL, FILL);
   
-  label = new Label(_("IP Address:"), 0, 0.5);
+  label = new Label(_("IP address:"), 0, 0.5);
   attach(*manage(label), 1, 2, 1, 2, FILL, FILL);
   
-  label = new Label(_("Network Mask:"), 0, 0.5);
+  label = new Label(_("Network mask:"), 0, 0.5);
   attach(*manage(label), 1, 2, 2, 3, FILL, FILL);
   
-  label = new Label(_("Prefix Length:"), 0, 0.5);
+  label = new Label(_("Prefix length:"), 0, 0.5);
   attach(*manage(label), 1, 2, 3, 4, FILL, FILL);
   
   label = new Label("");
@@ -140,22 +140,22 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   image->set_padding(12, 0);
   attach(*manage(image), 0, 1, 6, 12, FILL, FILL);
   
-  label = new Label(_("Address Range:"), 0, 0.5);
+  label = new Label(_("Address range:"), 0, 0.5);
   attach(*manage(label), 1, 2, 6, 7, FILL, FILL);
   
-  label = new Label(_("Number of Subnets:"), 0, 0.5);
+  label = new Label(_("Number of subnets:"), 0, 0.5);
   attach(*manage(label), 1, 2, 7, 8, FILL, FILL);
   
-  label = new Label(_("Number of Hosts:"), 0, 0.5);
+  label = new Label(_("Number of hosts:"), 0, 0.5);
   attach(*manage(label), 1, 2, 8, 9, FILL, FILL);
   
-  label = new Label(_("Including Net/Broadcast:"), 0, 0.5);
+  label = new Label(_("Including net/broadcast:"), 0, 0.5);
   attach(*manage(label), 1, 2, 9, 10, FILL, FILL);
   
-  label = new Label(_("Network Address:"), 0, 0.5);
+  label = new Label(_("Network address:"), 0, 0.5);
   attach(*manage(label), 1, 2, 10, 11, FILL, FILL);
   
-  label = new Label(_("Broadcast Address:"), 0, 0.5);
+  label = new Label(_("Broadcast address:"), 0, 0.5);
   attach(*manage(label), 1, 2, 11, 12, FILL, FILL);
   
   label = new Label("");
@@ -187,11 +187,11 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   widgets["out_broadcast"] = label;
   attach(*manage(label), 2, 3, 11, 12, FILL|EXPAND, FILL);
   
-  // ****************** "Output (Binary)" section ******************.
+  // ****************** "Binary Output" section ******************.
   // Add all labels.
   label = new Label("", 0, 0.5);
   str = "<b>";
-  str.append(_("Output (Binary)"));
+  str.append(_("Binary Output"));
   str.append("</b>");
   label->set_markup(str);
   label->set_padding(0, 6);
@@ -201,18 +201,21 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   image->set_padding(12, 0);
   attach(*manage(image), 0, 1, 14, 18, FILL, FILL);
   
-  label = new Label(_("IP Address:"), 0, 0.5);
+  label = new Label(_("IP address:"), 0, 0.5);
   attach(*manage(label), 1, 2, 14, 15, FILL, FILL);
   
-  label = new Label(_("Network Mask:"), 0, 0.5);
+  label = new Label(_("Network mask:"), 0, 0.5);
   attach(*manage(label), 1, 2, 15, 16, FILL, FILL);
   
-  label = new Label(_("Network Address:"), 0, 0.5);
+  label = new Label(_("Network address:"), 0, 0.5);
   attach(*manage(label), 1, 2, 16, 17, FILL, FILL);
   
-  label = new Label(_("Broadcast Address:"), 0, 0.5);
+  label = new Label(_("Broadcast address:"), 0, 0.5);
   attach(*manage(label), 1, 2, 17, 18, FILL, FILL);
   
+  label = new Label("");
+  attach(*manage(label), 0, 5, 18, 19, FILL, FILL);
+  
   // Add all entry boxes.
   label = new Label("", 0, 0.5);
   label->set_selectable();
@@ -233,6 +236,53 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   label->set_selectable();
   widgets["bin_broadcast"] = label;
   attach(*manage(label), 2, 5, 17, 18, FILL|EXPAND, FILL);
+  
+  // ****************** "Hexadecimal Output" section ******************.
+  // Add all labels.
+  label = new Label("", 0, 0.5);
+  str = "<b>";
+  str.append(_("Hexadecimal Output"));
+  str.append("</b>");
+  label->set_markup(str);
+  label->set_padding(0, 6);
+  attach(*manage(label), 0, 5, 19, 20, FILL, FILL);
+  
+  image = new Image(PACKAGE_PIXMAPS_DIR "gears.png");
+  image->set_padding(12, 0);
+  attach(*manage(image), 0, 1, 20, 24, FILL, FILL);
+  
+  label = new Label(_("IP address:"), 0, 0.5);
+  attach(*manage(label), 1, 2, 20, 21, FILL, FILL);
+  
+  label = new Label(_("Network mask:"), 0, 0.5);
+  attach(*manage(label), 1, 2, 21, 22, FILL, FILL);
+  
+  label = new Label(_("Network address:"), 0, 0.5);
+  attach(*manage(label), 1, 2, 22, 23, FILL, FILL);
+  
+  label = new Label(_("Broadcast address:"), 0, 0.5);
+  attach(*manage(label), 1, 2, 23, 24, FILL, FILL);
+  
+  // Add all entry boxes.
+  label = new Label("", 0, 0.5);
+  label->set_selectable();
+  widgets["hex_ip"] = label;
+  attach(*manage(label), 2, 5, 20, 21, FILL|EXPAND, FILL);
+  
+  label = new Label("", 0, 0.5);
+  label->set_selectable();
+  widgets["hex_mask"] = label;
+  attach(*manage(label), 2, 5, 21, 22, FILL|EXPAND, FILL);
+  
+  label = new Label("", 0, 0.5);
+  label->set_selectable();
+  widgets["hex_network"] = label;
+  attach(*manage(label), 2, 5, 22, 23, FILL|EXPAND, FILL);
+  
+  label = new Label("", 0, 0.5);
+  label->set_selectable();
+  widgets["hex_broadcast"] = label;
+  attach(*manage(label), 2, 5, 23, 24, FILL|EXPAND, FILL);
 }
 
 
@@ -452,6 +502,66 @@ void GUIIPv4Analyzer::set_output_bin_broadcast(unsigned long broadcast)
 }
 
 
+/* Sets the value of the "Output (Hexadecimal)" -> "IP" field. */
+void GUIIPv4Analyzer::set_output_hex_ip(unsigned long ip)
+{
+#ifdef _DEBUG_
+  printf("GUIIPv4Analyzer::set_output_hex_ip(): Called.\n");
+#endif
+  Label* label = (Label*)widgets["hex_ip"];
+  char hex[20];
+  if (ipv4_integer2hex(ip, hex) == 0)
+    label->set_text(hex);
+  else
+    label->set_text("");
+}
+
+
+/* Sets the value of the "Output (Hexadecimal)" -> "Netmask" field. */
+void GUIIPv4Analyzer::set_output_hex_mask(unsigned long mask)
+{
+#ifdef _DEBUG_
+  printf("GUIIPv4Analyzer::set_output_hex_mask(): Called.\n");
+#endif
+  Label* label = (Label*)widgets["hex_mask"];
+  char hex[20];
+  if (ipv4_integer2hex(mask, hex) == 0)
+    label->set_text(hex);
+  else
+    label->set_text("");
+}
+
+
+/* Sets the value of the "Output (Hexadecimal)" -> "Network Address" field. */
+void GUIIPv4Analyzer::set_output_hex_network(unsigned long net)
+{
+#ifdef _DEBUG_
+  printf("GUIIPv4Analyzer::set_output_hex_network(): Called.\n");
+#endif
+  Label* label = (Label*)widgets["hex_network"];
+  char hex[20];
+  if (ipv4_integer2hex(net, hex) == 0)
+    label->set_text(hex);
+  else
+    label->set_text("");
+}
+
+
+/* Sets the value of the "Output (Hexadecimal)" -> "Broadcast Address" field. */
+void GUIIPv4Analyzer::set_output_hex_broadcast(unsigned long broadcast)
+{
+#ifdef _DEBUG_
+  printf("GUIIPv4Analyzer::set_output_hex_broadcast(): Called.\n");
+#endif
+  Label* label = (Label*)widgets["hex_broadcast"];
+  char hex[20];
+  if (ipv4_integer2hex(broadcast, hex) == 0)
+    label->set_text(hex);
+  else
+    label->set_text("");
+}
+
+
 /******************************************************************************
  * Private
  ******************************************************************************/
