@@ -28,6 +28,7 @@
 #include <libintl.h>
 #include <map>
 #include "lib_ipv4.h"
+#include <sigc++/sigc++.h>
 
 #define _(String) gettext (String)
 #define gettext_noop(String) (String)
@@ -42,11 +43,11 @@ public:
   ~GUIIPv4Analyzer();
   
   /* Triggered whenever the IP field has been changed. */
-  SigC::Signal2<void, unsigned long, unsigned long>      signal_ip_changed;
+  sigc::signal2<void, unsigned long, unsigned long>      signal_ip_changed;
   /* Triggered whenever the netmask field has been changed. */
-  SigC::Signal2<void, unsigned long, unsigned long>      signal_mask_changed;
+  sigc::signal2<void, unsigned long, unsigned long>      signal_mask_changed;
   /* Triggered whenever the prefixlength field has been changed. */
-  SigC::Signal2<void, unsigned long, unsigned short int> signal_pfxlen_changed;
+  sigc::signal2<void, unsigned long, unsigned short int> signal_pfxlen_changed;
   
   /* Switch event emissions off. */
   void lock_signals(void);
