@@ -29,7 +29,7 @@
  * Constructor/Destructor
  ******************************************************************************/
 GUIIPv4SubnetCalculator::GUIIPv4SubnetCalculator()
-: label_range(_("Address Range:")),
+: label_range(_("Address range:")),
   label_dash("-")
 {
   resize(2, 4);
