@@ -29,9 +29,9 @@
  * Constructor/Destructor
  ******************************************************************************/
 GUIIPv4SubnetSplitter::GUIIPv4SubnetSplitter()
-: label_range(_("Address Range:"), 0, 0.5),
+: label_range(_("Address range:"), 0, 0.5),
   label_dash("-"),
-  label_pfxlen(_("Subnetted using Prefixlength:"), 0, 0.5),
+  label_pfxlen(_("Subnetted using prefixlength:"), 0, 0.5),
   label_maxmatch(_("Showing a maximum of 1000 subnets."), 1, 0.5)
 {
   resize(4, 4);
